import { useEffect, useState } from 'react';

import { LOCAL_STORAGE, msgTypes, msgSrcs } from '../utils/constants/common';

const useConversation = ({
  api = process.env.REACT_APP_CHAT_AGENT_URL, ivaAgentId, isWidgetPreviewOpen, isEditMode,
}) => {
  const getSoundSettings = localStorage.getItem(LOCAL_STORAGE.GET_SOUND_SETTINGS) !== 'false';

  const [socket, setSocket] = useState();
  const [conversation, setConversation] = useState([]);
  const [unreadMessagesCount, setUnreadMessagesCount] = useState(0);

  const [isSoundOn, setIsSoundOn] = useState(getSoundSettings ?? true);

  const notificationAudio = new Audio('https://cdn.simplyask.ai/widget/notificationSound.wav');

  useEffect(() => {
    if (isWidgetPreviewOpen) setUnreadMessagesCount(0);
  }, [isWidgetPreviewOpen]);

  useEffect(() => {
    if (!isWidgetPreviewOpen && conversation?.length > 0 && !isEditMode) {
      setUnreadMessagesCount((prev) => prev + 1);
      isSoundOn && notificationAudio?.play().catch((error) => console.log(error));
    }
  }, [conversation]);

  useEffect(() => {
    if (api && ivaAgentId) {
      const socketConnection = new WebSocket(api);
      socketConnection.onopen = () => {
        socketConnection.send(
          JSON.stringify({
            type: msgTypes.SET_IVA_AGENT_ID,
            contents: { data: ivaAgentId },
          }),
        );

        setSocket(socketConnection);
      };
    }
  }, [api, ivaAgentId]);

  useEffect(() => {
    if (!socket) return;

    const handleMessage = (msg) => {
      const { type } = msg.message;

      if (type === msgTypes.TEXT || type === msgTypes.FILE) {
        addMsgToConv(msg);
      }
    };

    socket.onmessage = (e) => {
      const msg = JSON.parse(e.data);

      handleMessage(msg);
    };
  }, [socket]);

  const addMsgToConv = (msg, format = false, src = msgSrcs.USER) => {
    const res = format ? { message: { ...msg }, messageSource: src, transmissionTime: new Date() } : msg;

    setConversation((prev) => [...prev, res]);
  };

  const sendMsg = (text) => {
    if (text === '') return;

    const msg = getMsgModel({ data: text });
    addMsgToConv(msg, true);

    socket.send(JSON.stringify(msg));
  };

  const sendFile = (fileData) => {
    const message = getMsgModel({
      type: msgTypes.FILE,
      data: fileData,
    });

    addMsgToConv(message, true);
    socket.send(JSON.stringify(message));
  };

  const getMsgModel = ({
    type = msgTypes.TEXT, data = '', fromName = '', fromEmail = '',
  }) => ({
    type,
    contents: {
      data,
      fromName,
      fromEmail,
    },
  });

  const toggleSoundSettings = () => {
    const toggleValue = !isSoundOn;
    setIsSoundOn(toggleValue);
    localStorage.setItem(LOCAL_STORAGE.GET_SOUND_SETTINGS, toggleValue);

    toggleValue && notificationAudio?.play().catch((err) => console.log(err));
  };

  return {
    conversation, unreadMessagesCount, isSoundOn, toggleSoundSettings, sendMsg, sendFile,
  };
};

export default useConversation;
