import React from 'react';
import { Route } from 'react-router-dom';
import forbidden from '../../assets/images/forbidden.png';
import lockedAccount from '../../assets/images/lockedAccount.svg';
import classes from './ProtectedRoute.module.css';

const ProtectedRoute = ({
  component: Component,
  alternativeComponent: AlternativeComponent,
  visible,
  readOnly,
  isAccountDisabled,
  isAccountDisabledText = 'to unknown reasons',
  isManagerRouteActivated = false,
  ...otherProps
}) => {
  const LockedAccountComponent = () => {
    return (
      <div className={`${classes.card}`}>
        <div className={classes.lockedAccountImageParent}>
          <img src={lockedAccount} alt='lockedAccount' className={classes.lockedAccountImage} />
        </div>

        <div className={classes.lockedAccountFirstTextParent}>
          <div className={classes.lockedAccountFirstText}>Oh No!</div>
        </div>

        <div className={classes.lockedAccountSecondTextParent}>
          <div className={classes.lockedAccountSecondText}>
            Your account has been disabled due {isAccountDisabledText}
          </div>
        </div>

        <div className={classes.lockedAccountSecondTextParent}>
          <div className={classes.lockedAccountThirdText}>
            Please contact the SimplyAsk team for more information
          </div>
        </div>

        <div className={classes.lockedAccountLastTextParent}>
          <div className={classes.lockedAccountFourthText}>info@simplyask.ai</div>
        </div>
      </div>
    );
  };

  return (
    <Route
      {...otherProps}
      render={(props) =>
        isAccountDisabled ? (
          <div className={classes.parentRoot}>
            <div className={classes.fullScreen}>
              <LockedAccountComponent />
            </div>
          </div>
        ) : visible ? (
          <div
            className={`${classes.parentRoot} ${
              isManagerRouteActivated && classes.isManagerRouteActivated
            }`}
          >
            <div className={`${readOnly ? classes.readOnly : classes.root}
            ${isManagerRouteActivated && classes.isManagerRouteActivatedRoot}`}>
              <Component readOnly={readOnly}  {...otherProps} />
            </div>
          </div>
        ) : AlternativeComponent ? (
          <AlternativeComponent readOnly={readOnly}  {...otherProps} />
        ) : (
          <img alt='Not Authorized' src={forbidden} className={classes.notAuthorized} />
        )
      }
    />
  );
};

export default ProtectedRoute;
