import React, { useState, useEffect } from 'react';
import Close from '@mui/icons-material/Close';
import DoubleArrow from '@mui/icons-material/DoubleArrow';
import Backdrop from '../Backdrop/Backdrop';
import classes from './SidedrawerModal.module.css';
import { Portal } from 'react-portal';

const SidedrawerModal = ({
  show,
  closeModal,
  children,
  hasCloseButton = true,
  width = '50vw',
  padding = '27',
  hasShrinkButton = false,
  styles,
  closeBtnClassName,
  useCloseBtnClassName = false,
  disableBackdropColor = false,
  className,
  setIsShrinkingValue = () => {},
  portalNode = document.body,
  noPortal
}) => {
  const [isShrinking, setIsShrinking] = useState(false);

  const handleShrinkButtonClick = () => {
    setIsShrinking((prevValue) => !prevValue);
  };

  useEffect(() => {
    setIsShrinkingValue(isShrinking);
  }, [isShrinking]);

  const renderSideDrawer = () => {
    return (
      <>
        {!isShrinking && !disableBackdropColor && <Backdrop show={show} clicked={closeModal} />}
        <div
          className={`${classes.root} ${show && classes.show} ${
            isShrinking && classes.isShrinkingModal
          } ${className}`}
          style={{
            '--sidedrawer-modal-width': width,
            '--sidedrawer-modal-padding': `${padding}px`,
            ...styles,
          }}
        >
          {hasCloseButton && (
            <Close
              className={`${useCloseBtnClassName ? closeBtnClassName : classes.closeIcon}`}
              onClick={closeModal}
            />
          )}
          {hasShrinkButton && (
            <div className={classes.shrinkContainer} onClick={handleShrinkButtonClick}>
              <DoubleArrow className={`${classes.shrinkIcon} ${isShrinking && classes.rotate}`} />
            </div>
          )}
          {children}
        </div>
      </>
    )
  }

  return noPortal ? renderSideDrawer() : (
    <Portal node={portalNode}>
      {renderSideDrawer()}
    </Portal>
  );
};

export default SidedrawerModal;
