import React from 'react';
import Pagination from '../Pagination/Pagination';
import { Icon } from '@iconify/react';
import Scrollbars from 'react-custom-scrollbars-2';
import ConditionalWrapper from '../ConditionalWrapper/ConditionalWrapper';
import { accessObjectProperty } from '../../utils/helperFunctions';
import classes from './Table.module.css';
import NoDataFound from '../../assets/images/NoDataFound.png';

const Table = ({
  data,
  pagination,
  headers,
  uniqueIdSrc,
  onClick,
  isLoading,
  onPageChange,
  isScrollable,
  scrollHeight,
  className,
  tableParentClassName,
  tableStyle,
  noDataFoundTitle,
  noDataFoundCaption,
  noDataFoundParentHeight = '60vh',
  paginationTextEnd = 'tickets',
}) => {
  const getHeaders = () => {
    return headers.map(({ name, alignCenter }, index) => (
      <th key={index} className={alignCenter && classes.alignCenter}>
        {name}
      </th>
    ));
  };

  const getTableData = () => {
    return data.map((row, index) => (
      <tr
        key={index}
        className={onClick && classes.clickable}
        onClick={(event) => onClick && onClick(accessObjectProperty(row, uniqueIdSrc), event)}
      >
        {headers.map(({ formatter, bold, source, subtitle, icon, alignCenter, renderImgIcon }, index) => {
          let result = formatter
            ? formatter(accessObjectProperty(row, source))
            : accessObjectProperty(row, source);

          if (icon) {
            return (
              <td
                className={`${bold && classes.bold} ${classes.iconContainer} ${
                  alignCenter && classes.alignCenter
                }`}
                key={index}
              >
                <Icon className={classes.icon} icon={icon.formatter(accessObjectProperty(row, icon.source))} />
                <div>
                  {result}
                  {subtitle && (
                    <span className={classes.subtitle}>
                      {subtitle.formatter
                        ? subtitle.formatter(accessObjectProperty(row, subtitle.source))
                        : accessObjectProperty(row, subtitle.source)}
                    </span>
                  )}
                </div>
              </td>
            );
          }

          if (renderImgIcon) {
            return (
              <td
                className={`${bold && classes.bold} ${classes.iconContainer} ${
                  alignCenter && classes.alignCenter
                }`}
                key={index}
              >
                <img src={renderImgIcon} className={classes.image} alt='' />
                <div>
                  {result}
                  {subtitle && (
                    <span className={classes.subtitle}>
                      {subtitle.formatter
                        ? subtitle.formatter(accessObjectProperty(row, subtitle.source))
                        : accessObjectProperty(row, subtitle.source)}
                    </span>
                  )}
                </div>
              </td>
            );
          }

          return (
            <td className={`${bold && classes.bold} ${alignCenter && classes.alignCenter}`} key={index}>
              {result}
              {subtitle ? (
                <span className={classes.subtitle}>
                  {subtitle.formatter
                    ? subtitle.formatter(accessObjectProperty(row, subtitle.source))
                    : accessObjectProperty(row, subtitle.source)}
                </span>
              ) : null}
            </td>
          );
        })}
      </tr>
    ));
  };

  return (
    !isLoading && (
      <div className={`${classes.root} ${tableParentClassName}`}>
        <ConditionalWrapper
          condition={isScrollable}
          wrapper={(children) => (
            <Scrollbars style={scrollHeight ? scrollHeight : {}} autoHide>
              {children}
            </Scrollbars>
          )}
        >
          <div>
            <table className={className}>
              <thead className={classes.table_header}>
                <tr>{getHeaders()}</tr>
              </thead>

              {data?.length > 0 && <tbody>{getTableData()}</tbody>}
            </table>

            {data?.length < 1 && (
              <div className={classes.noDataFoundParent} style={{ height: noDataFoundParentHeight }}>
                <div className={classes.noDataFoundChild}>
                  <div className={classes.noDataFoundImageParent}>
                    <img className={classes.noDataFoundImage} src={NoDataFound} alt='' />
                  </div>
                  <div className={classes.noDataFoundTextParent}>
                    <p className={classes.noDataFoundText}>
                      {noDataFoundTitle ? noDataFoundTitle : 'No Data Found'}
                    </p>
                    {noDataFoundCaption && <p className={classes.noDataFoundTextCaption}>{noDataFoundCaption}</p>}
                  </div>
                </div>
              </div>
            )}
          </div>
        </ConditionalWrapper>

        {pagination && (
          <div className={`${tableStyle} ${classes.bottom}`}>
            <p>
              Showing {pagination.startingPoint} - {pagination.endingPoint} of {pagination.totalElements}{' '}
              {paginationTextEnd}
            </p>
            <Pagination
              initialPage={pagination.pageNumber}
              totalPages={pagination.totalPages}
              onPageChange={onPageChange}
            />
          </div>
        )}
      </div>
    )
  );
};

export default Table;
