import React from 'react';
import { Tabs as MuiTabs, Tab } from '@mui/material';
import { makeStyles } from '@mui/styles';
import colors from '../../config/colors';
import classes from './Tabs.module.css';

const Tabs = ({
  labels,
  onChange,
  value,
  margin = '0px',
  activeBarHeight = '3',
  activeBarColor = colors.primary,
  className,
  ...otherProps
}) => {
  const useStyles = makeStyles(() => ({
    root: {
      '& .Mui-selected': {
        fontWeight: 'bolder',
      },
    },
    indicator: {
      backgroundColor: activeBarColor,
      height: `${activeBarHeight}px`,
    },
  }));
  const tabsClasses = useStyles();

  return (
    <MuiTabs
      value={value}
      className={`${classes.root} ${className}`}
      onChange={onChange}
      {...otherProps}
      style={{ '--tabs-margin': margin }}
      classes={{ root: tabsClasses.root, indicator: tabsClasses.indicator }}
    >
      {labels.map(({ title, unread, Icon }) => (
        <Tab label={title} key={title} unread-count={unread === 0 ? null : unread} icon={Icon || null} />
      ))}
    </MuiTabs>
  );
};

export default Tabs;
